core.match_filter.helpers
-------------------------

.. currentmodule:: eqcorrscan.core.match_filter.helpers
.. automodule:: eqcorrscan.core.match_filter.helpers

    .. comment to end block

    Functions
    ---------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       extract_from_stream
       normxcorr2
       temporary_directory

    .. comment to end block